*************************************************************
AGS Toolbox - Utility to manage different AGS Editor versions
*************************************************************

AGS Toolbox is a PyQt tool to manage different versions of the
Adventure Game Studio Editor, side by side, along with your
game projects!


Windows install and run
-----------------------

In Windows, install Python 3, and then open `cmd.exe` and type (press enter after):

    python -m pip install agstoolbox

To run, you can type the following in `cmd.exe` or the `run...` prompt

    python -m agstoolbox